Class PullRequestCommentProducer
java.lang.Object
org.apache.camel.support.service.BaseService
org.apache.camel.support.service.ServiceSupport
org.apache.camel.support.DefaultProducer
org.apache.camel.component.github2.producer.AbstractGitHub2Producer
org.apache.camel.component.github2.producer.PullRequestCommentProducer
- All Implemented Interfaces:
AutoCloseable, org.apache.camel.EndpointAware, org.apache.camel.IsSingleton, org.apache.camel.Processor, org.apache.camel.Producer, org.apache.camel.Service, org.apache.camel.ShutdownableService, org.apache.camel.StatefulService, org.apache.camel.SuspendableService
Producer endpoint that adds a comment on a GitHub pull request.
The endpoint requires the "GitHubPullRequest" header, identifying the pull request number (integer). If the
"GitHubInResponseTo" header is provided (identifying a comment ID), the comment will be a reply to that comment (if
supported).
-
Field Summary
Fields inherited from class org.apache.camel.support.service.BaseService
BUILT, FAILED, INITIALIZED, INITIALIZING, lock, NEW, SHUTDOWN, SHUTTING_DOWN, STARTED, STARTING, status, STOPPED, STOPPING, SUSPENDED, SUSPENDING -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class AbstractGitHub2Producer
doInit, getEndpoint, getGitHub, getRepositoryMethods inherited from class org.apache.camel.support.DefaultProducer
createExchange, doStart, doStop, isSingleton, toStringMethods inherited from class org.apache.camel.support.service.BaseService
build, doBuild, doFail, doLifecycleChange, doResume, doShutdown, doSuspend, fail, getInternalLock, getStatus, init, isBuild, isInit, isNew, isRunAllowed, isShutdown, isStarted, isStarting, isStartingOrStarted, isStopped, isStopping, isStoppingOrStopped, isSuspended, isSuspending, isSuspendingOrSuspended, resume, shutdown, start, stop, suspendMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.apache.camel.Service
build, close, init, start, stopMethods inherited from interface org.apache.camel.ShutdownableService
shutdownMethods inherited from interface org.apache.camel.StatefulService
getStatus, isRunAllowed, isStarted, isStarting, isStopped, isStopping, isSuspendingMethods inherited from interface org.apache.camel.SuspendableService
isSuspended, resume, suspend
-
Constructor Details
-
PullRequestCommentProducer
-
-
Method Details
-
process
- Specified by:
processin interfaceorg.apache.camel.Processor- Specified by:
processin classAbstractGitHub2Producer- Throws:
Exception
-