All Classes and Interfaces
Class
Description
Producer endpoint that closes a pull request.
Producer endpoint that creates an issue.
Producer endpoint that gets a file from a commit.
Represents the component that manages
GitHub2Endpoint.Generated by camel build tools - do NOT edit this file!
Interact with the GitHub API.
Generated by camel build tools - do NOT edit this file!
Generated by camel build tools - do NOT edit this file!
Strategy for fetching GitHub events.
Factory for creating GitHub client instances.
Producer endpoint that adds a comment on a GitHub pull request.
Producer endpoint that gets the list of files in a pull request.
Producer endpoint that sets the commit status.